<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="商品" prop="goodsId">
        <el-select v-model="queryParams.goodsId" filterable placeholder="请选择" style="width:100%">
          <el-option
            v-for="item in goodsList"
            :key="item.goodsId"
            :label="item.goodsName+'\t'+'\t'+item.className"
            :value="item.goodsId">
            <span style="float: left">{{ item.goodsName }}</span>
            <span style="float: right; color: #8492a6; font-size: 13px">{{ item.className }}</span>
          </el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="状态" prop="status">
        <el-select v-model="queryParams.status" placeholder="请选择状态" clearable size="small">
          <el-option label="显示" value="0" />
          <el-option label="隐藏" value="1" />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['mall:mallCombineGoods:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['mall:mallCombineGoods:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['mall:mallCombineGoods:remove']"
        >删除</el-button>
      </el-col>
<!--      <el-col :span="1.5">-->
<!--        <el-button-->
<!--          type="warning"-->
<!--          plain-->
<!--          icon="el-icon-download"-->
<!--          size="mini"-->
<!--          :loading="exportLoading"-->
<!--          @click="handleExport"-->
<!--          v-hasPermi="['mall:mallCombineGoods:export']"-->
<!--        >导出</el-button>-->
<!--      </el-col>-->
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="mallCombineGoodsList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
<!--      <el-table-column label="拼团商品主键ID" align="center" prop="combineId" />-->
<!--      <el-table-column label="商品ID" align="center" prop="goodsId" />-->
      <el-table-column label="商品名称" align="center" prop="goodsName" />
      <el-table-column label="商品标题" align="center" prop="goodsTitle" />
      <el-table-column label="商品logo" align="center" prop="goodsImg" >
        <template slot-scope="scope">
          <el-image :src="scope.row.goodsImg" style="width: 80px" :preview-src-list="[scope.row.goodsImg]"/>
        </template>
      </el-table-column>
      <el-table-column label="商品分类" align="center" prop="className" />
      <el-table-column label="拼团价" align="center" prop="price" />
      <el-table-column label="库存" align="center" prop="stock" />
      <el-table-column label="拼团人数" align="center" prop="peopleNum" />
      <el-table-column label="结束时间（分钟）" align="center" prop="endMinute" width="140px" />
<!--      <el-table-column label="时间ID" align="center" prop="timeId" />-->
<!--      <el-table-column label="结束时间" align="center" prop="endTime" />-->
      <el-table-column label="销量" align="center" prop="saleNum" />
<!--      <el-table-column label="限购" align="center" prop="purchaseLimits" />-->
      <el-table-column label="状态" align="center" prop="status" >
        <template slot-scope="scope">
          <div v-if="scope.row.status == 0">显示</div>
          <div v-if="scope.row.status == 1">隐藏</div>
        </template>
      </el-table-column>
      <el-table-column label="创建时间" align="center" prop="createAt" />
<!--      <el-table-column label="更新时间" align="center" prop="updateAt" />-->
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['mall:mallCombineGoods:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['mall:mallCombineGoods:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改拼团商品对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="600px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="商品" prop="goodsId">
          <el-select v-model="form.goodsId" filterable placeholder="请选择" style="width:100%">
            <el-option
              v-for="item in goodsList"
              :key="item.goodsId"
              :label="item.goodsName+'\t'+'\t'+item.className"
              :value="item.goodsId">
              <span style="float: left">{{ item.goodsName }}</span>
              <span style="float: right; color: #8492a6; font-size: 13px">{{ item.className }}</span>
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="拼团价" prop="price">
          <el-input v-model="form.price" placeholder="请输入拼团价" />
        </el-form-item>
        <el-form-item label="库存" prop="stock">
          <el-input-number v-model="form.stock" controls-position="right" :min="0" placeholder="请输入库存" />
        </el-form-item>
        <el-form-item label="拼团人数" prop="peopleNum">
          <el-input-number v-model="form.peopleNum" controls-position="right" :min="2" placeholder="请输入拼团人数" />
        </el-form-item>
        <el-form-item label="结束时间（分钟）" prop="endMinute">
          <el-input-number v-model="form.endMinute" controls-position="right" :min="2" placeholder="请输入结束时间（分钟）" />
        </el-form-item>
<!--        <el-form-item label="时间ID" prop="timeId">-->
<!--          <el-input v-model="form.timeId" placeholder="请输入时间ID" />-->
<!--        </el-form-item>-->
<!--        <el-form-item label="结束时间" prop="endTime">-->
<!--          <el-input v-model="form.endTime" placeholder="请输入结束时间" />-->
<!--        </el-form-item>-->
<!--        <el-form-item label="销量" prop="saleNum">-->
<!--          <el-input v-model="form.saleNum" placeholder="请输入销量" />-->
<!--        </el-form-item>-->
<!--        <el-form-item label="限购" prop="purchaseLimits">-->
<!--          <el-input v-model="form.purchaseLimits" placeholder="请输入限购" />-->
<!--        </el-form-item>-->
        <el-form-item label="状态" prop="status">
          <template>
            <el-radio v-model="form.status" :label="0">显示</el-radio>
            <el-radio v-model="form.status" :label="1">隐藏</el-radio>
          </template>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listMallCombineGoods,
  getMallCombineGoods,
  delMallCombineGoods,
  addMallCombineGoods,
  updateMallCombineGoods,
  exportMallCombineGoods,
  enableCombineGoodsList
} from "@/api/mall/mallCombineGoods";

export default {
  name: "MallCombineGoods",
  data() {
    return {
      goodsList:[],
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 拼团商品表格数据
      mallCombineGoodsList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        goodsId: null,
        price: null,
        stock: null,
        peopleNum: null,
        endMinute: null,
        timeId: null,
        endTime: null,
        saleNum: null,
        purchaseLimits: null,
        status: null,
        createAt: null,
        updateAt: null,
        delFlag: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        goodsId: [
          { required: true, message: "商品不能为空", trigger: "blur" }
        ],
        price: [
          { required: true, message: "拼团价不能为空", trigger: "blur" }
        ],
        stock: [
          { required: true, message: "库存不能为空", trigger: "blur" }
        ],
        peopleNum: [
          { required: true, message: "拼团人数不能为空", trigger: "blur" }
        ],
        endMinute: [
          { required: true, message: "结束时间（分钟）不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
    enableCombineGoodsList().then(res =>{
      this.goodsList = res.data
    });
  },
  methods: {
    /** 查询拼团商品列表 */
    getList() {
      this.loading = true;
      listMallCombineGoods(this.queryParams).then(response => {
        this.mallCombineGoodsList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        combineId: null,
        goodsId: null,
        price: null,
        stock: null,
        peopleNum: null,
        endMinute: null,
        timeId: null,
        endTime: null,
        saleNum: null,
        purchaseLimits: null,
        status: 0,
        createAt: null,
        updateAt: null,
        delFlag: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.combineId)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加拼团商品";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const combineId = row.combineId || this.ids
      getMallCombineGoods(combineId).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改拼团商品";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.combineId != null) {
            updateMallCombineGoods(this.form).then(response => {
              this.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addMallCombineGoods(this.form).then(response => {
              this.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const combineIds = row.combineId || this.ids;
      this.$confirm('是否确认删除拼团商品编号为"' + combineIds + '"的数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return delMallCombineGoods(combineIds);
        }).then(() => {
          this.getList();
          this.msgSuccess("删除成功");
        }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm('是否确认导出所有拼团商品数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(() => {
          this.exportLoading = true;
          return exportMallCombineGoods(queryParams);
        }).then(response => {
          this.download(response.msg);
          this.exportLoading = false;
        }).catch(() => {});
    }
  }
};
</script>
